summaryrefslogtreecommitdiff
path: root/clients/tui/nmt-password-dialog.c
diff options
context:
space:
mode:
Diffstat (limited to 'clients/tui/nmt-password-dialog.c')
-rw-r--r--clients/tui/nmt-password-dialog.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/clients/tui/nmt-password-dialog.c b/clients/tui/nmt-password-dialog.c
index 22ba85d2c5..aeece1211f 100644
--- a/clients/tui/nmt-password-dialog.c
+++ b/clients/tui/nmt-password-dialog.c
@@ -29,7 +29,7 @@
#include <glib/gi18n-lib.h>
#include "nmt-password-dialog.h"
-#include "nmt-secret-agent.h"
+#include "nm-secret-agent-simple.h"
#include "nmtui.h"
G_DEFINE_TYPE (NmtPasswordDialog, nmt_password_dialog, NMT_TYPE_NEWT_FORM)
@@ -60,10 +60,10 @@ enum {
/**
* nmt_password_dialog_new:
* @request_id: the request ID from the #NmtSecretAgent
* @title: the dialog title
* @prompt: the prompt text to display
* @secrets: (element-type #NmtSecretAgentSecret): the secrets requested
*
* Creates a new #NmtPasswordDialog to request passwords from
* the user.
@@ -109,7 +109,7 @@ maybe_save_input_and_exit (NmtNewtWidget *widget,
priv->succeeded = TRUE;
for (i = 0; i < priv->secrets->len; i++) {
- NmtSecretAgentSecret *secret = priv->secrets->pdata[i];
+ NMSecretAgentSimpleSecret *secret = priv->secrets->pdata[i];
g_free (secret->value);
g_object_get (priv->entries->pdata[i], "text", &secret->value, NULL);
@@ -143,7 +143,7 @@ nmt_password_dialog_constructed (GObject *object)
secret_grid = NMT_NEWT_GRID (widget);
for (i = 0; i < priv->secrets->len; i++) {
- NmtSecretAgentSecret *secret = priv->secrets->pdata[i];
+ NMSecretAgentSimpleSecret *secret = priv->secrets->pdata[i];
NmtNewtEntryFlags flags;
widget = nmt_newt_label_new (secret->name);
@@ -258,7 +258,7 @@ nmt_password_dialog_class_init (NmtPasswordDialogClass *dialog_class)
/**
* NmtPasswordDialog:request-id:
*
- * The request ID from the #NmtSecretAgent
+ * The request ID from the #NMSecretAgentSimple
*/
g_object_class_install_property
(object_class, PROP_REQUEST_ID,
@@ -284,7 +284,7 @@ nmt_password_dialog_class_init (NmtPasswordDialogClass *dialog_class)
*
* The array of request secrets
*
- * Element-Type: #NmtSecretAgentSecret.
+ * Element-Type: #NMSecretAgentSimpleSecret.
*/
g_object_class_install_property
(object_class, PROP_SECRETS,
@@ -60,10 +60,10 @@ enum {
/**
* nmt_password_dialog_new:
- * @request_id: the request ID from the #NmtSecretAgent
+ * @request_id: the request ID from the #NMSecretAgentSimple
* @title: the dialog title
* @prompt: the prompt text to display
@@ -60,10 +60,10 @@ enum {
* @title: the dialog title
* @prompt: the prompt text to display
- * @secrets: (element-type #NmtSecretAgentSecret): the secrets requested
+ * @secrets: (element-type #NMSecretAgentSimpleSecret): the secrets requested
*
* Creates a new #NmtPasswordDialog to request passwords from